epubbuilder
===========

fork of http://code.google.com/p/python-epub-builder/

This is a small python library for programmatically building EPUB books. It provides API for easily constructing and packaging EPUBs from text content. 

Prerequisits
------------

```
easy_install Genshi
```
